measuretools.Measure
====================

.. abjad-lineage:: abjad.tools.measuretools.Measure.Measure.Measure

.. autoclass:: abjad.tools.measuretools.Measure.Measure.Measure

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.measuretools.Measure.Measure.Measure.always_format_time_signature
      ~abjad.tools.measuretools.Measure.Measure.Measure.append
      ~abjad.tools.measuretools.Measure.Measure.Measure.automatically_adjust_time_signature
      ~abjad.tools.measuretools.Measure.Measure.Measure.extend
      ~abjad.tools.measuretools.Measure.Measure.Measure.has_non_power_of_two_denominator
      ~abjad.tools.measuretools.Measure.Measure.Measure.has_power_of_two_denominator
      ~abjad.tools.measuretools.Measure.Measure.Measure.implied_prolation
      ~abjad.tools.measuretools.Measure.Measure.Measure.index
      ~abjad.tools.measuretools.Measure.Measure.Measure.insert
      ~abjad.tools.measuretools.Measure.Measure.Measure.is_full
      ~abjad.tools.measuretools.Measure.Measure.Measure.is_misfilled
      ~abjad.tools.measuretools.Measure.Measure.Measure.is_overfull
      ~abjad.tools.measuretools.Measure.Measure.Measure.is_simultaneous
      ~abjad.tools.measuretools.Measure.Measure.Measure.is_underfull
      ~abjad.tools.measuretools.Measure.Measure.Measure.lilypond_format
      ~abjad.tools.measuretools.Measure.Measure.Measure.measure_number
      ~abjad.tools.measuretools.Measure.Measure.Measure.override
      ~abjad.tools.measuretools.Measure.Measure.Measure.pop
      ~abjad.tools.measuretools.Measure.Measure.Measure.remove
      ~abjad.tools.measuretools.Measure.Measure.Measure.reverse
      ~abjad.tools.measuretools.Measure.Measure.Measure.scale_and_adjust_time_signature
      ~abjad.tools.measuretools.Measure.Measure.Measure.select
      ~abjad.tools.measuretools.Measure.Measure.Measure.select_leaves
      ~abjad.tools.measuretools.Measure.Measure.Measure.select_notes_and_chords
      ~abjad.tools.measuretools.Measure.Measure.Measure.set
      ~abjad.tools.measuretools.Measure.Measure.Measure.storage_format
      ~abjad.tools.measuretools.Measure.Measure.Measure.target_duration
      ~abjad.tools.measuretools.Measure.Measure.Measure.time_signature
      ~abjad.tools.measuretools.Measure.Measure.Measure.__add__
      ~abjad.tools.measuretools.Measure.Measure.Measure.__contains__
      ~abjad.tools.measuretools.Measure.Measure.Measure.__copy__
      ~abjad.tools.measuretools.Measure.Measure.Measure.__delitem__
      ~abjad.tools.measuretools.Measure.Measure.Measure.__eq__
      ~abjad.tools.measuretools.Measure.Measure.Measure.__getitem__
      ~abjad.tools.measuretools.Measure.Measure.Measure.__len__
      ~abjad.tools.measuretools.Measure.Measure.Measure.__mul__
      ~abjad.tools.measuretools.Measure.Measure.Measure.__ne__
      ~abjad.tools.measuretools.Measure.Measure.Measure.__repr__
      ~abjad.tools.measuretools.Measure.Measure.Measure.__rmul__
      ~abjad.tools.measuretools.Measure.Measure.Measure.__setitem__
      ~abjad.tools.measuretools.Measure.Measure.Measure.__str__

Bases
-----

- :py:class:`containertools.FixedDurationContainer <abjad.tools.containertools.FixedDurationContainer.FixedDurationContainer.FixedDurationContainer>`

- :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

- :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.measuretools.Measure.Measure.Measure.has_non_power_of_two_denominator
   :noindex:

.. autoattribute:: abjad.tools.measuretools.Measure.Measure.Measure.has_power_of_two_denominator
   :noindex:

.. autoattribute:: abjad.tools.measuretools.Measure.Measure.Measure.implied_prolation
   :noindex:

.. autoattribute:: abjad.tools.measuretools.Measure.Measure.Measure.is_full
   :noindex:

.. autoattribute:: abjad.tools.measuretools.Measure.Measure.Measure.is_misfilled
   :noindex:

.. autoattribute:: abjad.tools.measuretools.Measure.Measure.Measure.is_overfull
   :noindex:

.. autoattribute:: abjad.tools.measuretools.Measure.Measure.Measure.is_underfull
   :noindex:

.. autoattribute:: abjad.tools.measuretools.Measure.Measure.Measure.lilypond_format
   :noindex:

.. autoattribute:: abjad.tools.measuretools.Measure.Measure.Measure.measure_number
   :noindex:

.. autoattribute:: abjad.tools.measuretools.Measure.Measure.Measure.override
   :noindex:

.. autoattribute:: abjad.tools.measuretools.Measure.Measure.Measure.set
   :noindex:

.. autoattribute:: abjad.tools.measuretools.Measure.Measure.Measure.storage_format
   :noindex:

.. autoattribute:: abjad.tools.measuretools.Measure.Measure.Measure.target_duration
   :noindex:

.. autoattribute:: abjad.tools.measuretools.Measure.Measure.Measure.time_signature
   :noindex:

Read/write properties
---------------------

.. autoattribute:: abjad.tools.measuretools.Measure.Measure.Measure.always_format_time_signature
   :noindex:

.. autoattribute:: abjad.tools.measuretools.Measure.Measure.Measure.automatically_adjust_time_signature
   :noindex:

.. autoattribute:: abjad.tools.measuretools.Measure.Measure.Measure.is_simultaneous
   :noindex:

Methods
-------

.. automethod:: abjad.tools.measuretools.Measure.Measure.Measure.append
   :noindex:

.. automethod:: abjad.tools.measuretools.Measure.Measure.Measure.extend
   :noindex:

.. automethod:: abjad.tools.measuretools.Measure.Measure.Measure.index
   :noindex:

.. automethod:: abjad.tools.measuretools.Measure.Measure.Measure.insert
   :noindex:

.. automethod:: abjad.tools.measuretools.Measure.Measure.Measure.pop
   :noindex:

.. automethod:: abjad.tools.measuretools.Measure.Measure.Measure.remove
   :noindex:

.. automethod:: abjad.tools.measuretools.Measure.Measure.Measure.reverse
   :noindex:

.. automethod:: abjad.tools.measuretools.Measure.Measure.Measure.scale_and_adjust_time_signature
   :noindex:

.. automethod:: abjad.tools.measuretools.Measure.Measure.Measure.select
   :noindex:

.. automethod:: abjad.tools.measuretools.Measure.Measure.Measure.select_leaves
   :noindex:

.. automethod:: abjad.tools.measuretools.Measure.Measure.Measure.select_notes_and_chords
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.measuretools.Measure.Measure.Measure.__add__
   :noindex:

.. automethod:: abjad.tools.measuretools.Measure.Measure.Measure.__contains__
   :noindex:

.. automethod:: abjad.tools.measuretools.Measure.Measure.Measure.__copy__
   :noindex:

.. automethod:: abjad.tools.measuretools.Measure.Measure.Measure.__delitem__
   :noindex:

.. automethod:: abjad.tools.measuretools.Measure.Measure.Measure.__eq__
   :noindex:

.. automethod:: abjad.tools.measuretools.Measure.Measure.Measure.__getitem__
   :noindex:

.. automethod:: abjad.tools.measuretools.Measure.Measure.Measure.__len__
   :noindex:

.. automethod:: abjad.tools.measuretools.Measure.Measure.Measure.__mul__
   :noindex:

.. automethod:: abjad.tools.measuretools.Measure.Measure.Measure.__ne__
   :noindex:

.. automethod:: abjad.tools.measuretools.Measure.Measure.Measure.__repr__
   :noindex:

.. automethod:: abjad.tools.measuretools.Measure.Measure.Measure.__rmul__
   :noindex:

.. automethod:: abjad.tools.measuretools.Measure.Measure.Measure.__setitem__
   :noindex:

.. automethod:: abjad.tools.measuretools.Measure.Measure.Measure.__str__
   :noindex:
